"use strict";(self.webpackChunk_JUPYTERLAB_CORE_OUTPUT=self.webpackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([[5254],{95254:(e,a,t)=>{t.r(a),t.d(a,{default:()=>i});var r=t(53312),s=t(12030);const i={id:"@jupyterlab/theme-dark-high-contrast-extension:plugin",description:"Adds a dark high contrast theme.",requires:[r.IThemeManager,s.ITranslator],activate:(e,a,t)=>{const r=t.load("jupyterlab");a.register({name:"JupyterLab Dark High Contrast",displayName:r.__("JupyterLab Dark High Contrast"),isLight:!1,themeScrollbars:!0,load:()=>a.loadCSS("@jupyterlab/theme-dark-high-contrast-extension/index.css"),unload:()=>Promise.resolve(void 0)})},autoStart:!0}}}]);